==> bitfront-library-6.0.0.tgz: package/src/app/developerlibrary/log/log-list-tableview.component.ts <==
import {Component,
        Input}              from '@angular/core';
import {Item}               from '../../shared/index';
import {MessageService}     from '../../shared/service/message.service';
import {BitMessage}         from '../../shared/index';

@Component({

    selector: 'log-list-tableview',
    template: `
<p-dataTable [value]="items" *ngIf="(items != null && items.length > 0)">
    <p-column field="login" header="Login" [sortable]="true"></p-column>
    <p-column field="concepto" header="Concepto" [sortable]="true"></p-column>
    <p-column field="tipo" header="Operación" [sortable]="true"></p-column>
    <p-column field="fecha" header="Hora" [sortable]="true">
        <ng-template let-log="rowData" pTemplate type="body">
            <span>{{log.fecha | date:"HH:mm"}}</span>
        </ng-template>
    </p-column> 
    <p-column styleClass="col-button">
        <ng-template let-log="rowData" pTemplate type="body">
            <div class="btn-group" role="group">
                <button [disabled]="!log.datos" class="btn btn-default btn-xs"  (click)="showDatosLog($event,log.datos,'Dades enviades');">Enviat&nbsp;&nbsp;<span class="glyphicon glyphicon-log-in"></span></button>
            </div>
            <div class="btn-group" role="group">
                <button *ngIf="!log.error" class="btn btn-default btn-xs" (click)="showDatosLog($event,log.respuesta,'Resposta');"> Resposta&nbsp;&nbsp;<span class="glyphicon glyphicon-log-out"></span>
                </button>
                <button *ngIf="log.error" class="btn btn-danger btn-xs" (click)="showDatosLog($event,log.error,'Error');"> Error&nbsp;&nbsp;<span class="glyphicon glyphicon-alert"></span>
                </button>
            </div>
        </ng-template>
    </p-column>
</p-dataTable>
    `
})
export class LogListTableViewComponent {
    @Input() items: Item[];

    constructor(private messageService: MessageService) {}

    /** Muestra los datos de log en un diálogo*/
    showDatosLog(event, log: string, titulo: string) {
        let width: number = BitMessage.WIDTH;
        let json: boolean = true;
        if (titulo === 'Error') {
            width = 800;
            json = false;
        }
        let bitMessage: BitMessage =  new BitMessage(titulo, log, width);
        bitMessage.json = json;
        this.messageService.sendMessage(bitMessage);
    }

}

==> bitfront-library-6.6.2.tgz: package/src/app/developerlibrary/log/log-list-tableview.component.ts <==
import {Component,
        Input}              from '@angular/core';
import {MessageService}     from '../../shared/service/message.service';
import { Item } from '../../shared/data/item';
import { BitMessage } from '../../shared/data/bitmessage';

@Component({

    selector: 'log-list-tableview',
    template: `
<p-dataTable [value]="items" *ngIf="(items != null && items.length > 0)">
    <p-column field="login" header="Login" [sortable]="true"></p-column>
    <p-column field="concepto" header="Concepto" [sortable]="true"></p-column>
    <p-column field="tipo" header="Operación" [sortable]="true"></p-column>
    <p-column field="fecha" header="Hora" [sortable]="true">
        <ng-template let-log="rowData" pTemplate type="body">
            <span>{{log.fecha | date:"HH:mm"}}</span>
        </ng-template>
    </p-column> 
    <p-column styleClass="col-button">
        <ng-template let-log="rowData" pTemplate type="body">
            <div class="btn-group" role="group">
                <button [disabled]="!log.datos" class="btn btn-default btn-xs"  (click)="showDatosLog($event,log.datos,'Dades enviades');">Enviat&nbsp;&nbsp;<span class="glyphicon glyphicon-log-in"></span></button>
            </div>
            <div class="btn-group" role="group">
                <button *ngIf="!log.error && log.respuesta" class="btn btn-default btn-xs" (click)="showDatosLog($event,log.respuesta,'Resposta');"> Resposta&nbsp;&nbsp;<span class="glyphicon glyphicon-log-out"></span>
                </button>
                <button *ngIf="log.error" class="btn btn-danger btn-xs" (click)="showDatosLog($event,log.error,'Error');"> Error&nbsp;&nbsp;<span class="glyphicon glyphicon-alert"></span>
                </button>
            </div>
        </ng-template>
    </p-column>
</p-dataTable>
    `
})
export class LogListTableViewComponent {
    @Input() items: Item[];

    constructor(private messageService: MessageService) {}

    /** Muestra los datos de log en un diálogo*/
    showDatosLog(event, log: string, titulo: string) {
        let width: number = BitMessage.WIDTH;
        let json: boolean = true;
        if (titulo === 'Error') {
            width = 800;
            json = false;
        }
        let bitMessage: BitMessage =  new BitMessage(titulo, log, width);
        bitMessage.json = json;
        this.messageService.sendMessage(bitMessage);
    }

}
